/**
    @file ft51_aio_registers.h

    @brief Analogue IO registers library

    Defines registers and bit-masks associated with analogue input/output.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_AIO_REGISTERS_H__
#define __FT51_AIO_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 10 (0xA) DIGITAL_CONTROL_AIO_0
#define DIGITAL_CONTROL_AIO_0             0xA

// Register 10 Bit Definitions
#define BIT_AIO_0_DRIVE_STRENGTH_0            0                                 // AIO Pad 0 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_0_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_0_DRIVE_STRENGTH_0)
#define BIT_AIO_0_DRIVE_STRENGTH_1            1                                 // AIO Pad 0 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_0_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_0_DRIVE_STRENGTH_1)
#define MASK_AIO_0_DRIVE_STRENGTH             (0x3 << BIT_AIO_0_DRIVE_STRENGTH_0)
#define BIT_AIO_0_PUENA                       2                                 // AIO Pad 0 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_0_PUENA                      (0x1 << BIT_AIO_0_PUENA)
#define BIT_AIO_0_PDENA                       3                                 // AIO Pad 0 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_0_PDENA                      (0x1 << BIT_AIO_0_PDENA)
#define BIT_AIO_0_SMT                         4                                 // AIO Pad 0 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_0_SMT                        (0x1 << BIT_AIO_0_SMT)
#define BIT_AIO_0_SR                          5                                 // AIO Pad 0 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_0_SR                         (0x1 << BIT_AIO_0_SR)

//------------------------------------------------------------------------------
// Register 11 (0xB) DIGITAL_CONTROL_AIO_1
#define DIGITAL_CONTROL_AIO_1             0xB

// Register 11 Bit Definitions
#define BIT_AIO_1_DRIVE_STRENGTH_0            0                                 // AIO Pad 1 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_1_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_1_DRIVE_STRENGTH_0)
#define BIT_AIO_1_DRIVE_STRENGTH_1            1                                 // AIO Pad 1 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_1_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_1_DRIVE_STRENGTH_1)
#define MASK_AIO_1_DRIVE_STRENGTH             (0x3 << BIT_AIO_1_DRIVE_STRENGTH_0)
#define BIT_AIO_1_PUENA                       2                                 // AIO Pad 1 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_1_PUENA                      (0x1 << BIT_AIO_1_PUENA)
#define BIT_AIO_1_PDENA                       3                                 // AIO Pad 1 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_1_PDENA                      (0x1 << BIT_AIO_1_PDENA)
#define BIT_AIO_1_SMT                         4                                 // AIO Pad 1 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_1_SMT                        (0x1 << BIT_AIO_1_SMT)
#define BIT_AIO_1_SR                          5                                 // AIO Pad 1 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_1_SR                         (0x1 << BIT_AIO_1_SR)

//------------------------------------------------------------------------------
// Register 12 (0xC) DIGITAL_CONTROL_AIO_2
#define DIGITAL_CONTROL_AIO_2             0xC

// Register 12 Bit Definitions
#define BIT_AIO_2_DRIVE_STRENGTH_0            0                                 // AIO Pad 2 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_2_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_2_DRIVE_STRENGTH_0)
#define BIT_AIO_2_DRIVE_STRENGTH_1            1                                 // AIO Pad 2 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_2_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_2_DRIVE_STRENGTH_1)
#define MASK_AIO_2_DRIVE_STRENGTH             (0x3 << BIT_AIO_2_DRIVE_STRENGTH_0)
#define BIT_AIO_2_PUENA                       2                                 // AIO Pad 2 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_2_PUENA                      (0x1 << BIT_AIO_2_PUENA)
#define BIT_AIO_2_PDENA                       3                                 // AIO Pad 2 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_2_PDENA                      (0x1 << BIT_AIO_2_PDENA)
#define BIT_AIO_2_SMT                         4                                 // AIO Pad 2 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_2_SMT                        (0x1 << BIT_AIO_2_SMT)
#define BIT_AIO_2_SR                          5                                 // AIO Pad 2 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_2_SR                         (0x1 << BIT_AIO_2_SR)

//------------------------------------------------------------------------------
// Register 13 (0xD) DIGITAL_CONTROL_AIO_3
#define DIGITAL_CONTROL_AIO_3             0xD

// Register 13 Bit Definitions
#define BIT_AIO_3_DRIVE_STRENGTH_0            0                                 // AIO Pad 3 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_3_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_3_DRIVE_STRENGTH_0)
#define BIT_AIO_3_DRIVE_STRENGTH_1            1                                 // AIO Pad 3 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_3_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_3_DRIVE_STRENGTH_1)
#define MASK_AIO_3_DRIVE_STRENGTH             (0x3 << BIT_AIO_3_DRIVE_STRENGTH_0)
#define BIT_AIO_3_PUENA                       2                                 // AIO Pad 3 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_3_PUENA                      (0x1 << BIT_AIO_3_PUENA)
#define BIT_AIO_3_PDENA                       3                                 // AIO Pad 3 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_3_PDENA                      (0x1 << BIT_AIO_3_PDENA)
#define BIT_AIO_3_SMT                         4                                 // AIO Pad 3 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_3_SMT                        (0x1 << BIT_AIO_3_SMT)
#define BIT_AIO_3_SR                          5                                 // AIO Pad 3 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_3_SR                         (0x1 << BIT_AIO_3_SR)

//------------------------------------------------------------------------------
// Register 14 (0xE) DIGITAL_CONTROL_AIO_4
#define DIGITAL_CONTROL_AIO_4             0xE

// Register 14 Bit Definitions
#define BIT_AIO_4_DRIVE_STRENGTH_0            0                                 // AIO Pad 4 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_4_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_4_DRIVE_STRENGTH_0)
#define BIT_AIO_4_DRIVE_STRENGTH_1            1                                 // AIO Pad 4 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_4_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_4_DRIVE_STRENGTH_1)
#define MASK_AIO_4_DRIVE_STRENGTH             (0x3 << BIT_AIO_4_DRIVE_STRENGTH_0)
#define BIT_AIO_4_PUENA                       2                                 // AIO Pad 4 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_4_PUENA                      (0x1 << BIT_AIO_4_PUENA)
#define BIT_AIO_4_PDENA                       3                                 // AIO Pad 4 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_4_PDENA                      (0x1 << BIT_AIO_4_PDENA)
#define BIT_AIO_4_SMT                         4                                 // AIO Pad 4 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_4_SMT                        (0x1 << BIT_AIO_4_SMT)
#define BIT_AIO_4_SR                          5                                 // AIO Pad 4 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_4_SR                         (0x1 << BIT_AIO_4_SR)
#define BIT_AIO_4_PUENA_24_OR_32              6                                 // AIO Pad 4 Pull Up Enable when in 24 or 32 pin package (difference is it defaults to on). 0 - Disabled. 1 - Enabled.
#define MASK_AIO_4_PUENA_24_OR_32             (0x1 << BIT_AIO_4_PUENA_24_OR_32)

//------------------------------------------------------------------------------
// Register 15 (0xF) DIGITAL_CONTROL_AIO_5
#define DIGITAL_CONTROL_AIO_5             0xF

// Register 15 Bit Definitions
#define BIT_AIO_5_DRIVE_STRENGTH_0            0                                 // AIO Pad 5 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_5_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_5_DRIVE_STRENGTH_0)
#define BIT_AIO_5_DRIVE_STRENGTH_1            1                                 // AIO Pad 5 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_5_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_5_DRIVE_STRENGTH_1)
#define MASK_AIO_5_DRIVE_STRENGTH             (0x3 << BIT_AIO_5_DRIVE_STRENGTH_0)
#define BIT_AIO_5_PUENA                       2                                 // AIO Pad 5 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_5_PUENA                      (0x1 << BIT_AIO_5_PUENA)
#define BIT_AIO_5_PDENA                       3                                 // AIO Pad 5 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_5_PDENA                      (0x1 << BIT_AIO_5_PDENA)
#define BIT_AIO_5_SMT                         4                                 // AIO Pad 5 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_5_SMT                        (0x1 << BIT_AIO_5_SMT)
#define BIT_AIO_5_SR                          5                                 // AIO Pad 5 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_5_SR                         (0x1 << BIT_AIO_5_SR)
#define BIT_AIO_5_PUENA_24_OR_32              6                                 // AIO Pad 5 Pull Up Enable when in 24 or 32 pin package (difference is it defaults to on). 0 - Disabled. 1 - Enabled.
#define MASK_AIO_5_PUENA_24_OR_32             (0x1 << BIT_AIO_5_PUENA_24_OR_32)

//------------------------------------------------------------------------------
// Register 16 (0x10) DIGITAL_CONTROL_AIO_6
#define DIGITAL_CONTROL_AIO_6             0x10

// Register 16 Bit Definitions
#define BIT_AIO_6_DRIVE_STRENGTH_0            0                                 // AIO Pad 6 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_6_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_6_DRIVE_STRENGTH_0)
#define BIT_AIO_6_DRIVE_STRENGTH_1            1                                 // AIO Pad 6 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_6_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_6_DRIVE_STRENGTH_1)
#define MASK_AIO_6_DRIVE_STRENGTH             (0x3 << BIT_AIO_6_DRIVE_STRENGTH_0)
#define BIT_AIO_6_PUENA                       2                                 // AIO Pad 5 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_6_PUENA                      (0x1 << BIT_AIO_6_PUENA)
#define BIT_AIO_6_PDENA                       3                                 // AIO Pad 5 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_6_PDENA                      (0x1 << BIT_AIO_6_PDENA)
#define BIT_AIO_6_SMT                         4                                 // AIO Pad 6 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_6_SMT                        (0x1 << BIT_AIO_6_SMT)
#define BIT_AIO_6_SR                          5                                 // AIO Pad 6 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_6_SR                         (0x1 << BIT_AIO_6_SR)
#define BIT_AIO_6_PUENA_24_OR_32              6                                 // AIO Pad 6 Pull Up Enable when in 24 or 32 pin package (difference is it defaults to on). 0 - Disabled. 1 - Enabled.
#define MASK_AIO_6_PUENA_24_OR_32             (0x1 << BIT_AIO_6_PUENA_24_OR_32)

//------------------------------------------------------------------------------
// Register 17 (0x11) DIGITAL_CONTROL_AIO_7
#define DIGITAL_CONTROL_AIO_7             0x11

// Register 17 Bit Definitions
#define BIT_AIO_7_DRIVE_STRENGTH_0            0                                 // AIO Pad 7 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_7_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_7_DRIVE_STRENGTH_0)
#define BIT_AIO_7_DRIVE_STRENGTH_1            1                                 // AIO Pad 7 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_7_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_7_DRIVE_STRENGTH_1)
#define MASK_AIO_7_DRIVE_STRENGTH             (0x3 << BIT_AIO_7_DRIVE_STRENGTH_0)
#define BIT_AIO_7_PUENA                       2                                 // AIO Pad 7 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_7_PUENA                      (0x1 << BIT_AIO_7_PUENA)
#define BIT_AIO_7_PDENA                       3                                 // AIO Pad 7 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_7_PDENA                      (0x1 << BIT_AIO_7_PDENA)
#define BIT_AIO_7_SMT                         4                                 // AIO Pad 7 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_7_SMT                        (0x1 << BIT_AIO_7_SMT)
#define BIT_AIO_7_SR                          5                                 // AIO Pad 7 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_7_SR                         (0x1 << BIT_AIO_7_SR)
#define BIT_AIO_7_PUENA_24_OR_32              6                                 // AIO Pad 7 Pull Up Enable when in 24 or 32 pin package (difference is it defaults to on). 0 - Disabled. 1 - Enabled.
#define MASK_AIO_7_PUENA_24_OR_32             (0x1 << BIT_AIO_7_PUENA_24_OR_32)

//------------------------------------------------------------------------------
// Register 18 (0x12) DIGITAL_CONTROL_AIO_8
#define DIGITAL_CONTROL_AIO_8             0x12

// Register 18 Bit Definitions
#define BIT_AIO_8_DRIVE_STRENGTH_0            0                                 // AIO Pad 8 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_8_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_8_DRIVE_STRENGTH_0)
#define BIT_AIO_8_DRIVE_STRENGTH_1            1                                 // AIO Pad 8 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_8_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_8_DRIVE_STRENGTH_1)
#define MASK_AIO_8_DRIVE_STRENGTH             (0x3 << BIT_AIO_8_DRIVE_STRENGTH_0)
#define BIT_AIO_8_PUENA                       2                                 // AIO Pad 8 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_8_PUENA                      (0x1 << BIT_AIO_8_PUENA)
#define BIT_AIO_8_PDENA                       3                                 // AIO Pad 8 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_8_PDENA                      (0x1 << BIT_AIO_8_PDENA)
#define BIT_AIO_8_SMT                         4                                 // AIO Pad 8 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_8_SMT                        (0x1 << BIT_AIO_8_SMT)
#define BIT_AIO_8_SR                          5                                 // AIO Pad 8 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_8_SR                         (0x1 << BIT_AIO_8_SR)

//------------------------------------------------------------------------------
// Register 19 (0x13) DIGITAL_CONTROL_AIO_9
#define DIGITAL_CONTROL_AIO_9             0x13

// Register 19 Bit Definitions
#define BIT_AIO_9_DRIVE_STRENGTH_0            0                                 // AIO Pad 9 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_9_DRIVE_STRENGTH_0           (0x1 << BIT_AIO_9_DRIVE_STRENGTH_0)
#define BIT_AIO_9_DRIVE_STRENGTH_1            1                                 // AIO Pad 9 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_9_DRIVE_STRENGTH_1           (0x1 << BIT_AIO_9_DRIVE_STRENGTH_1)
#define MASK_AIO_9_DRIVE_STRENGTH             (0x3 << BIT_AIO_9_DRIVE_STRENGTH_0)
#define BIT_AIO_9_PUENA                       2                                 // AIO Pad 9 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_9_PUENA                      (0x1 << BIT_AIO_9_PUENA)
#define BIT_AIO_9_PDENA                       3                                 // AIO Pad 9 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_9_PDENA                      (0x1 << BIT_AIO_9_PDENA)
#define BIT_AIO_9_SMT                         4                                 // AIO Pad 9 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_9_SMT                        (0x1 << BIT_AIO_9_SMT)
#define BIT_AIO_9_SR                          5                                 // AIO Pad 9 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_9_SR                         (0x1 << BIT_AIO_9_SR)

//------------------------------------------------------------------------------
// Register 20 (0x14) DIGITAL_CONTROL_AIO_10
#define DIGITAL_CONTROL_AIO_10            0x14

// Register 20 Bit Definitions
#define BIT_AIO_10_DRIVE_STRENGTH_0           0                                 // AIO Pad 10 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_10_DRIVE_STRENGTH_0          (0x1 << BIT_AIO_10_DRIVE_STRENGTH_0)
#define BIT_AIO_10_DRIVE_STRENGTH_1           1                                 // AIO Pad 10 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_10_DRIVE_STRENGTH_1          (0x1 << BIT_AIO_10_DRIVE_STRENGTH_1)
#define MASK_AIO_10_DRIVE_STRENGTH            (0x3 << BIT_AIO_10_DRIVE_STRENGTH_0)
#define BIT_AIO_10_PUENA                      2                                 // AIO Pad 10 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_10_PUENA                     (0x1 << BIT_AIO_10_PUENA)
#define BIT_AIO_10_PDENA                      3                                 // AIO Pad 10 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_10_PDENA                     (0x1 << BIT_AIO_10_PDENA)
#define BIT_AIO_10_SMT                        4                                 // AIO Pad 10 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_10_SMT                       (0x1 << BIT_AIO_10_SMT)
#define BIT_AIO_10_SR                         5                                 // AIO Pad 10 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_10_SR                        (0x1 << BIT_AIO_10_SR)

//------------------------------------------------------------------------------
// Register 21 (0x15) DIGITAL_CONTROL_AIO_11
#define DIGITAL_CONTROL_AIO_11            0x15

// Register 21 Bit Definitions
#define BIT_AIO_11_DRIVE_STRENGTH_0           0                                 // AIO Pad 11 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_11_DRIVE_STRENGTH_0          (0x1 << BIT_AIO_11_DRIVE_STRENGTH_0)
#define BIT_AIO_11_DRIVE_STRENGTH_1           1                                 // AIO Pad 11 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_11_DRIVE_STRENGTH_1          (0x1 << BIT_AIO_11_DRIVE_STRENGTH_1)
#define MASK_AIO_11_DRIVE_STRENGTH            (0x3 << BIT_AIO_11_DRIVE_STRENGTH_0)
#define BIT_AIO_11_PUENA                      2                                 // AIO Pad 11 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_11_PUENA                     (0x1 << BIT_AIO_11_PUENA)
#define BIT_AIO_11_PDENA                      3                                 // AIO Pad 11 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_11_PDENA                     (0x1 << BIT_AIO_11_PDENA)
#define BIT_AIO_11_SMT                        4                                 // AIO Pad 11 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_11_SMT                       (0x1 << BIT_AIO_11_SMT)
#define BIT_AIO_11_SR                         5                                 // AIO Pad 11 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_11_SR                        (0x1 << BIT_AIO_11_SR)

//------------------------------------------------------------------------------
// Register 22 (0x16) DIGITAL_CONTROL_AIO_12
#define DIGITAL_CONTROL_AIO_12            0x16

// Register 22 Bit Definitions
#define BIT_AIO_12_DRIVE_STRENGTH_0           0                                 // AIO Pad 12 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_12_DRIVE_STRENGTH_0          (0x1 << BIT_AIO_12_DRIVE_STRENGTH_0)
#define BIT_AIO_12_DRIVE_STRENGTH_1           1                                 // AIO Pad 12 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_12_DRIVE_STRENGTH_1          (0x1 << BIT_AIO_12_DRIVE_STRENGTH_1)
#define MASK_AIO_12_DRIVE_STRENGTH            (0x3 << BIT_AIO_12_DRIVE_STRENGTH_0)
#define BIT_AIO_12_PUENA                      2                                 // AIO Pad 12 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_12_PUENA                     (0x1 << BIT_AIO_12_PUENA)
#define BIT_AIO_12_PDENA                      3                                 // AIO Pad 12 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_12_PDENA                     (0x1 << BIT_AIO_12_PDENA)
#define BIT_AIO_12_SMT                        4                                 // AIO Pad 12 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_12_SMT                       (0x1 << BIT_AIO_12_SMT)
#define BIT_AIO_12_SR                         5                                 // AIO Pad 12 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_12_SR                        (0x1 << BIT_AIO_12_SR)

//------------------------------------------------------------------------------
// Register 23 (0x17) DIGITAL_CONTROL_AIO_13
#define DIGITAL_CONTROL_AIO_13            0x17

// Register 23 Bit Definitions
#define BIT_AIO_13_DRIVE_STRENGTH_0           0                                 // AIO Pad 13 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_13_DRIVE_STRENGTH_0          (0x1 << BIT_AIO_13_DRIVE_STRENGTH_0)
#define BIT_AIO_13_DRIVE_STRENGTH_1           1                                 // AIO Pad 13 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_13_DRIVE_STRENGTH_1          (0x1 << BIT_AIO_13_DRIVE_STRENGTH_1)
#define MASK_AIO_13_DRIVE_STRENGTH            (0x3 << BIT_AIO_13_DRIVE_STRENGTH_0)
#define BIT_AIO_13_PUENA                      2                                 // AIO Pad 13 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_13_PUENA                     (0x1 << BIT_AIO_13_PUENA)
#define BIT_AIO_13_PDENA                      3                                 // AIO Pad 13 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_13_PDENA                     (0x1 << BIT_AIO_13_PDENA)
#define BIT_AIO_13_SMT                        4                                 // AIO Pad 13 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_13_SMT                       (0x1 << BIT_AIO_13_SMT)
#define BIT_AIO_13_SR                         5                                 // AIO Pad 13 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_13_SR                        (0x1 << BIT_AIO_13_SR)

//------------------------------------------------------------------------------
// Register 24 (0x18) DIGITAL_CONTROL_AIO_14
#define DIGITAL_CONTROL_AIO_14            0x18

// Register 24 Bit Definitions
#define BIT_AIO_14_DRIVE_STRENGTH_0           0                                 // AIO Pad 14 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_14_DRIVE_STRENGTH_0          (0x1 << BIT_AIO_14_DRIVE_STRENGTH_0)
#define BIT_AIO_14_DRIVE_STRENGTH_1           1                                 // AIO Pad 14 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_14_DRIVE_STRENGTH_1          (0x1 << BIT_AIO_14_DRIVE_STRENGTH_1)
#define MASK_AIO_14_DRIVE_STRENGTH            (0x3 << BIT_AIO_14_DRIVE_STRENGTH_0)
#define BIT_AIO_14_PUENA                      2                                 // AIO Pad 14 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_14_PUENA                     (0x1 << BIT_AIO_14_PUENA)
#define BIT_AIO_14_PDENA                      3                                 // AIO Pad 14 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_14_PDENA                     (0x1 << BIT_AIO_14_PDENA)
#define BIT_AIO_14_SMT                        4                                 // AIO Pad 14 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_14_SMT                       (0x1 << BIT_AIO_14_SMT)
#define BIT_AIO_14_SR                         5                                 // AIO Pad 14 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_14_SR                        (0x1 << BIT_AIO_14_SR)

//------------------------------------------------------------------------------
// Register 25 (0x19) DIGITAL_CONTROL_AIO_15
#define DIGITAL_CONTROL_AIO_15            0x19

// Register 25 Bit Definitions
#define BIT_AIO_15_DRIVE_STRENGTH_0           0                                 // AIO Pad 15 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_15_DRIVE_STRENGTH_0          (0x1 << BIT_AIO_15_DRIVE_STRENGTH_0)
#define BIT_AIO_15_DRIVE_STRENGTH_1           1                                 // AIO Pad 15 Drive Strength Control. 1 - Low Drive. 2- Medium Drive. 3 - High Drive. Note For FT51L 0 indicates a weak drive strength.
#define MASK_AIO_15_DRIVE_STRENGTH_1          (0x1 << BIT_AIO_15_DRIVE_STRENGTH_1)
#define MASK_AIO_15_DRIVE_STRENGTH            (0x3 << BIT_AIO_15_DRIVE_STRENGTH_0)
#define BIT_AIO_15_PUENA                      2                                 // AIO Pad 15 Pull Up Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_15_PUENA                     (0x1 << BIT_AIO_15_PUENA)
#define BIT_AIO_15_PDENA                      3                                 // AIO Pad 15 Pull Down Enable. 0 - Disabled. 1 - Enabled.
#define MASK_AIO_15_PDENA                     (0x1 << BIT_AIO_15_PDENA)
#define BIT_AIO_15_SMT                        4                                 // AIO Pad 15 Schmitt Enable. 0 - Disabled. 1 - Enabled. Note: FT51L Only.
#define MASK_AIO_15_SMT                       (0x1 << BIT_AIO_15_SMT)
#define BIT_AIO_15_SR                         5                                 // AIO Pad 15 Slew Rate Control. 0 - Normal. 1 - Slow. Note: FT51L Only.
#define MASK_AIO_15_SR                        (0x1 << BIT_AIO_15_SR)

//------------------------------------------------------------------------------
// Register 42 (0x2A) AIO_DIFFERENTIAL_ENABLE
#define AIO_DIFFERENTIAL_ENABLE           0x2A

// Register 42 Bit Definitions
#define BIT_DIFF_0_1                        0                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_0_1                       (0x1 << BIT_DIFF_0_1)
#define BIT_DIFF_2_3                        1                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_2_3                       (0x1 << BIT_DIFF_2_3)
#define BIT_DIFF_4_5                        2                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_4_5                       (0x1 << BIT_DIFF_4_5)
#define BIT_DIFF_6_7                        3                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_6_7                       (0x1 << BIT_DIFF_6_7)
#define BIT_DIFF_8_9                        4                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_8_9                       (0x1 << BIT_DIFF_8_9)
#define BIT_DIFF_10_11                        5                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_10_11                       (0x1 << BIT_DIFF_10_11)
#define BIT_DIFF_12_13                        6                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_12_13                       (0x1 << BIT_DIFF_12_13)
#define BIT_DIFF_14_15                        7                                 // Enable a pair of pads for differential mode. Setting a bit will for example enable aio[1:0] as a differential pair.
#define MASK_DIFF_14_15                       (0x1 << BIT_DIFF_14_15)
#define MASK_DIFF_ENA                         (0xFF << BIT_DIFF_0_1)

#endif // __FT51_AIO_REGISTERS_H__
