/**
    @file ft51_lcd_st7036.c

    @brief LCD Library API ST7036 LCD functions.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */
#include <stdint.h>
#include "ft51_lcd.h"
#include "ft51_i2c_master.h"

void lcd_initialise(void)
{
    __code char cmd[] = 
    {
            0x38, // Function Set: DL=1 8-bit; N=1 2 line display; DH=0 single height; IS=00 instruction set 0
            0x39, // Function Set: DL=1 8-bit; N=1 2 line display; DH=0 single height; IS=01 instruction set 1
            0x14, // Bias Set: BS=0 bias 1/5
            0x78, // Contrast Set: C3=1
            0x5E, // Power/ICON/Contrast Control: Ion=1 ICON on; Bon=1 booster on; C5=0,C4=0
            0x6d, // Follower Control: Fon=1 follower on
            0x0c, // Display ON/OFF Control: D=1 display on; C=0 cursor off; B=0 blink off
            0x01, // Clear Display
            0x06, // Entry Mode Set: I/D=1 cursor moves right; S=0 no shift
    };

    I2C_master_write(0x78, 0x00, // Send Command
            cmd, sizeof(cmd));
}

void lcd_clear(void)
{
    __code char cmd_clear_display[] = 
    {
            0x01, // Clear display
    };

    I2C_master_write(0x78, 0x00, // Send Command
            cmd_clear_display, sizeof(cmd_clear_display));
}

void lcd_home(void)
{
    __code char cmd_cursor_home[] = 
    {
            0x02, // Clear display
    };

    I2C_master_write(0x78, 0x00, // Send Command
            cmd_cursor_home, sizeof(cmd_cursor_home));
}

void lcd_position(uint8_t line, uint8_t pos)
{
    char cmd_cursor_set[] = 
    {
            0x80, //
    };

    cmd_cursor_set[0] |= ((line * 0x40) + pos);
    I2C_master_write(0x78, 0x00, // Send Command
            cmd_cursor_set, sizeof(cmd_cursor_set));
}

void lcd_display(uint8_t *text, uint8_t len)
{
    I2C_master_write(0x78, 0x40, // Send Data
            text, len);
}
